@@ -1,14 +1,15 @@
+import copy
+import logging
+import os
+import warnings
+from datetime import datetime
+import unicodedata
+
+import editdistance
 import spacy
 import torch
-import editdistance
-from datetime import datetime
-import os
-import copy
-import warnings, logging
-
 from spacy.tokens import Doc, Token, Span
 from spacy.vocab import Vocab
-
 from transformers import AutoModelForMaskedLM, AutoTokenizer
 
 
@@ -43,9 +44,9 @@ class ContextualSpellCheck(object):
                                           Defaults to False.
         """
         if (
-            (type(vocab_path) != type(""))
-            or (type(debug) != type(True))
-            or (type(performance) != type(True))
+            not isinstance(vocab_path, str)
+            or not isinstance(debug, type(True))
+            or not isinstance(performance, type(True))
         ):
             raise TypeError(
                 "Please check datatype provided. vocab_path should be str,"
@@ -53,9 +54,10 @@ class ContextualSpellCheck(object):
             )
         try:
             int(float(max_edit_dist))
-        except ValueError as identifier:
+        except ValueError:
             raise ValueError(
-                f"cannot convert {max_edit_dist} to int. Please provide a valid integer"
+                f"cannot convert {max_edit_dist} to int. Please provide a "
+                f"valid integer "
             )
 
         if vocab_path != "":
@@ -182,7 +184,7 @@ class ContextualSpellCheck(object):
             (str, `Doc`): returns updated query (if no oov words then "")
                           and updated Doc Object
         """
-        if type(query) != str and len(query) == 0:
+        if not isinstance(query, str) and len(query) == 0:
             return "Invalid query, expected non empty `str` but passed", query
 
         nlp = spacy.load(spacy_model, disable=["tagger", "parser"])
@@ -250,8 +252,8 @@ class ContextualSpellCheck(object):
                 and (token.ent_type_ != "GPE")
                 and (token.ent_type_ != "ORG")
             ):
-                misspell.append(token)
-
+                if self.deep_tokenize_in_vocab(token.text):
+                    misspell.append(token)
         if self.debug:
             print("misspell identified: ", misspell)
         return misspell, doc
@@ -573,6 +575,59 @@ class ContextualSpellCheck(object):
 
         return update_query
 
+    def deep_tokenize_in_vocab(self, text):
+        """Check if the token contains punctuations
+            if char is punctuation then check in vocab
+            check rest of the word in vocab
+            if both in vocab return False
+
+        Args:
+            text (str): Text to tokenize again for punct
+
+        Returns:
+            Bool: True if both punct and rest of the word
+                 in vocab
+        """
+        text_len = len(text)
+        sub_tokens = []
+        pre_puct_position = -1
+        for char_position in range(text_len):
+            if unicodedata.category(text[char_position]).startswith("P"):
+                # print("current_pos is {} and sub_token append {}"
+                # .format(char_position,text[char_position]))
+                sub_tokens.append(text[char_position])
+                # print("pre_pos is {}, cur  is {} , pre to current is {}"
+                # .format(pre_puct_position,char_position,text[pre_puct_position+1:char_position]))
+                if (
+                    pre_puct_position >= 0
+                    and text[pre_puct_position + 1 : char_position] != ""
+                ):
+                    # print("pre_pos is {}, cur  is {} , pre to current is {}"
+                    # .format(pre_puct_position,char_position,text[pre_puct_position+1:char_position]))
+                    sub_tokens.append(
+                        text[pre_puct_position + 1 : char_position]
+                    )
+                pre_puct_position = char_position
+
+            if (
+                (len(sub_tokens) > 0)
+                and (char_position + 1 == text_len)
+                and (text[pre_puct_position + 1 :] != "")
+            ):
+                # print("inside last token append {}"
+                # .format(text[pre_puct_position+1:]))
+                sub_tokens.append(text[pre_puct_position + 1 :])
+
+        if len(sub_tokens) > 0:
+            for sub_token in sub_tokens:
+                print(sub_token in self.vocab)
+                if sub_token not in self.vocab:
+                    return True
+        else:
+            return True
+
+        return False
+
 
 if __name__ == "__main__":
     print("Code running...")
